package com.ynet.life.mvc;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.session.SessionException;
import com.ynet.gene.web.servlet.view.ExceptionView;
import com.ynet.life.base.LifeErrorInfo;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.error.ErrorMessageJDBC;
import com.ynet.life.format.LifeStringFilter;
import com.ynet.life.util.GENEDataUtils;
import java.io.IOException;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.ServletRequestUtils;

/* loaded from: com_ynet_life_mvc.jar:com/ynet/life/mvc/XMLView.class */
public class XMLView extends ExceptionView {
    private static final int XML_FORMAT_ELEMENT = 1;
    private static final int XML_FORMAT_ATTRIBUTE = 2;
    private String url;
    private String urlField;
    private String exceptionName;
    private String errorCode;
    private String tranCode;
    private String pkgid;

    public void render(Map model, HttpServletRequest request, HttpServletResponse response, String rootPath) {
        String language;
        response.addHeader("Cache-Control", "no-cache");
        response.addHeader("Content-Type", "application/xml");
        try {
            String srcChannel = (String) request.getAttribute("srcChannel");
            String responseFormat = ServletRequestUtils.getStringParameter(request, "format");
            Context context = (Context) model.get(GENEConstance.ATTR_CONTEXT);
            try {
                String parameter = request.getParameter(TEntity.language);
                language = parameter;
                if (StringUtils.isEmpty(parameter)) {
                    language = (String) context.getDataValue(TEntity.language);
                }
            } catch (Exception unused) {
                language = "ZH_CN";
            }
            if ("JRB".equals(srcChannel)) {
                renderPB(model, request, response, responseFormat, language);
                return;
            }
            String actionId = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
            Trace.logInfo("LifeAction", "XML视图实现类render方法找不到渠道标识,actionId:".concat(String.valueOf(actionId)));
            renderPB(model, request, response, responseFormat, language);
        } catch (Exception e) {
            Trace.logError("LifeAction", "XML视图实现类render方法处理失败", e);
        }
    }

    public void renderPB(Map model, HttpServletRequest request, HttpServletResponse response, String responseFormat, String language) {
        String data;
        try {
            String actionId = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
            if (!StringUtils.equals(responseFormat, "JSON") && StringUtils.equals(responseFormat, "XML")) {
                data = getXMLResponse(model, XML_FORMAT_ELEMENT);
            } else {
                data = renderJSONResponse(model, response, language, actionId);
            }
            response.getOutputStream().write(data.getBytes("UTF-8"));
            Trace.logInfo("LifeAction", data);
        } catch (Exception e) {
            Trace.logError("LifeAction", "XML视图实现类renderPB方法处理失败", e);
        }
    }

    public void renderMB(Map model, HttpServletRequest request, HttpServletResponse response, String responseFormat) {
        String data;
        try {
            if (StringUtils.equals(responseFormat, "JSON")) {
                data = renderJSONResponseMB(model, response);
            } else if (StringUtils.equals(responseFormat, "XML")) {
                this.tranCode = ServletRequestUtils.getStringParameter(request, "tranCode");
                this.pkgid = ServletRequestUtils.getStringParameter(request, "pkgid");
                data = getXMLResponseForMB(model, XML_FORMAT_ELEMENT);
            } else {
                data = getXMLResponseForMB(model, XML_FORMAT_ATTRIBUTE);
            }
            response.getOutputStream().write(data.getBytes("UTF-8"));
            Trace.logInfo("LifeAction", data);
        } catch (Exception e) {
            Trace.logError("LifeAction", "XML视图实现类renderMB方法处理失败", e);
        }
    }

    private String renderJSONResponse(Map model, HttpServletResponse response, String language, String actionId) throws IOException {
        String str;
        String synFlag = null;
        Context context = (Context) model.get(GENEConstance.ATTR_CONTEXT);
        KeyedCollection output = (KeyedCollection) model.get(GENEConstance.ATTR_FLOW_OUTPUT);
        LifeErrorInfo errorInfo = dealError(model, language, actionId);
        String rp = this.url;
        StringBuffer buf = new StringBuffer("");
        if (context != null && "0".equals(errorInfo.getErrorCode())) {
            LifeStringFilter.filterHtmlTagFromKeyedCollection(context.getDataElement());
            synFlag = (String) context.get("synCacheSessionData");
            if (rp == null && this.urlField != null) {
                rp = (String) context.get(this.urlField);
            }
            buf.append("{");
            if (output == null || !output.containsKey("errorCode") || output.size() != XML_FORMAT_ELEMENT) {
                KeyedCollection kColl = context.getDataElement();
                boolean fE = XML_FORMAT_ELEMENT;
                for (int i = 0; i < kColl.size(); i += XML_FORMAT_ELEMENT) {
                    try {
                        DataElement element = kColl.getDataElement(i);
                        String dataName = element.getName();
                        if ((((output == null || output.containsKey(dataName)) && !isFilterValue(dataName)) || "packageId".equals(dataName)) && (str = element.toJSon()) != null && str.length() > 0) {
                            if (!fE) {
                                buf.append(",");
                            } else {
                                fE = false;
                            }
                            buf.append("\"").append(dataName).append("\":");
                            buf.append(str);
                        }
                    } catch (InvalidArgumentException unused) {
                    }
                }
            }
            buf.append("}");
        }
        StringBuffer sb = new StringBuffer("{");
        sb.append("\"ec\":\"").append(errorInfo.getErrorCode()).append("\",");
        sb.append("\"em\":\"").append(errorInfo.getShowMsgJSON()).append("\",");
        if (rp != null) {
            sb.append("\"rp\":\"").append(rp).append("\",");
        }
        if (synFlag != null) {
            sb.append("\"syn\":\"").append(synFlag).append("\",");
        }
        if (buf.length() > 0) {
            sb.append("\"cd\":").append(buf.toString());
        } else {
            sb.append("\"cd\":\"\"");
        }
        sb.append("}");
        return sb.toString();
    }

    private String renderJSONResponseMB(Map model, HttpServletResponse response) throws IOException {
        Context context = (Context) model.get(GENEConstance.ATTR_CONTEXT);
        KeyedCollection output = (KeyedCollection) model.get(GENEConstance.ATTR_FLOW_OUTPUT);
        LifeErrorInfo errorInfo = dealError(model, "", "");
        String rp = this.url;
        StringBuffer buf = new StringBuffer("");
        if (context != null) {
            if (rp == null && this.urlField != null) {
                rp = (String) context.get(this.urlField);
            }
            buf.append("{");
            if (output == null || !output.containsKey("errorCode") || output.size() != XML_FORMAT_ELEMENT) {
                KeyedCollection kColl = context.getDataElement();
                boolean fE = XML_FORMAT_ELEMENT;
                for (int i = 0; i < kColl.size(); i += XML_FORMAT_ELEMENT) {
                    try {
                        DataElement element = kColl.getDataElement(i);
                        String dataName = element.getName();
                        if ((output == null || output.containsKey(dataName)) && !isFilterValue(dataName)) {
                            if (element instanceof IndexedCollection) {
                                dataName = "result";
                            }
                            String str = element.toJSon();
                            if (str != null && str.length() > 0) {
                                if (!fE) {
                                    buf.append(",");
                                } else {
                                    fE = false;
                                }
                                buf.append("\"").append(dataName).append("\":");
                                buf.append(str);
                            }
                        }
                    } catch (InvalidArgumentException unused) {
                    }
                }
            }
            buf.append("}");
        }
        StringBuffer sb = new StringBuffer("{");
        sb.append("\"ec\":\"").append(errorInfo.getErrorCode()).append("\",");
        sb.append("\"em\":\"").append(errorInfo.getShowMsgJSON()).append("\",");
        if (rp != null) {
            sb.append("\"rp\":\"").append(rp).append("\",");
        }
        sb.append("\"cd\":").append(buf.toString());
        sb.append("}");
        return sb.toString();
    }

    private String getXMLResponse(Map model, int xmlFormat) {
        String synFlag = null;
        StringBuffer sb = new StringBuffer();
        Context context = (Context) model.get(GENEConstance.ATTR_CONTEXT);
        KeyedCollection output = (KeyedCollection) model.get(GENEConstance.ATTR_FLOW_OUTPUT);
        LifeErrorInfo errorInfo = dealError(model, "", "");
        sb.append("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>");
        sb.append("<root>");
        sb.append("<ec>").append(errorInfo.getErrorCode()).append("</ec>");
        sb.append("<em>").append(errorInfo.getShowMsg()).append("</em>");
        String rp = this.url;
        StringBuffer cd = new StringBuffer("");
        if (context != null) {
            synFlag = (String) context.get("synCacheSessionData");
            if (rp == null && this.urlField != null) {
                rp = (String) context.get(this.urlField);
            }
            cd.append("<cd>");
            if (output == null || !output.containsKey("errorCode") || output.size() != XML_FORMAT_ELEMENT) {
                KeyedCollection contextData = context.getDataElement();
                if (xmlFormat == XML_FORMAT_ELEMENT) {
                    GENEDataUtils.getXML(cd, contextData, output);
                } else {
                    for (DataElement element : contextData.values()) {
                        String dataName = element.getName();
                        if (output == null || output.containsKey(dataName)) {
                            if (!isFilterValue(dataName)) {
                                cd.append(element.toString());
                            }
                        }
                    }
                }
            }
            cd.append("</cd>");
        }
        if (rp != null) {
            sb.append("<rp>").append(rp).append("</rp>");
        }
        if (synFlag != null) {
            sb.append("<syn>").append(synFlag).append("</syn>");
        }
        sb.append(cd.toString());
        sb.append("</root>");
        return sb.toString();
    }

    private String getXMLResponseForMB(Map model, int xmlFormat) {
        StringBuffer sb = new StringBuffer();
        Context context = (Context) model.get(GENEConstance.ATTR_CONTEXT);
        KeyedCollection output = (KeyedCollection) model.get(GENEConstance.ATTR_FLOW_OUTPUT);
        LifeErrorInfo errorInfo = dealError(model, "", "");
        sb.append("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>");
        sb.append("<root>");
        sb.append("<ec>").append(errorInfo.getErrorCode()).append("</ec>");
        sb.append("<em>").append(errorInfo.getShowMsg()).append("</em>");
        String rp = this.url;
        StringBuffer cd = new StringBuffer("");
        if (context != null) {
            if (rp == null && this.urlField != null) {
                rp = (String) context.get(this.urlField);
            }
            if (xmlFormat == XML_FORMAT_ELEMENT) {
                sb.append("<sc>").append(this.tranCode).append("</sc>");
                sb.append("<pkgid>").append(this.pkgid).append("</pkgid>");
            }
            cd.append("<cd>");
            if ((output == null || !output.containsKey("errorCode") || output.size() != XML_FORMAT_ELEMENT) && !StringUtils.equals(this.tranCode, "MB0000")) {
                KeyedCollection contextData = context.getDataElement();
                if (xmlFormat == XML_FORMAT_ELEMENT) {
                    GENEDataUtils.getXML(cd, contextData, output);
                } else {
                    for (DataElement element : contextData.values()) {
                        String dataName = element.getName();
                        if (output == null || output.containsKey(dataName)) {
                            if (!isFilterValue(dataName)) {
                                cd.append(element.toString());
                            }
                        }
                    }
                }
            }
            cd.append("</cd>");
        }
        if (rp != null) {
            sb.append("<rp>").append(rp).append("</rp>");
        }
        sb.append(cd.toString());
        sb.append("</root>");
        return sb.toString();
    }

    public LifeErrorInfo dealError(Map model, String language, String businessCode) {
        if (StringUtils.isEmpty(language)) {
            language = "ZH_CN";
        }
        Context context = (Context) model.get(GENEConstance.ATTR_CONTEXT);
        GENEException gENEException = (Exception) model.get(GENEConstance.ATTR_EXCEPTION);
        String errorCode = "";
        if (context != null) {
            errorCode = (String) context.get("errorCode");
        }
        String ec = "0";
        String errorMsg = "";
        if (gENEException != null) {
            if (this.errorCode != null && !"".equals(this.errorCode)) {
                String str = this.errorCode;
                ec = str;
                LifeErrorInfo errorInfo = LifeStandard.getErrorInfo(str, language);
                errorMsg = errorInfo != null ? errorInfo.getShowMsg() : "";
                if ("".equals(errorMsg) || errorMsg == null) {
                    errorMsg = gENEException.getMessage();
                }
            } else if (gENEException instanceof SessionException) {
                String errorCode2 = gENEException.getErrorCode();
                ec = errorCode2;
                if (errorCode2 == null || "20000".equals(ec) || "20100".equals(ec) || "".equals(ec)) {
                    ec = "EBLN1000";
                }
                LifeErrorInfo errorInfo2 = LifeStandard.getErrorInfo(ec);
                errorMsg = errorInfo2 != null ? errorInfo2.getShowMsg() : "";
                if ("".equals(errorMsg) || errorMsg == null) {
                    errorMsg = gENEException.getShowMessage();
                }
            } else if (gENEException instanceof GENEException) {
                String errorCode3 = gENEException.getErrorCode();
                ec = errorCode3;
                if (errorCode3 == null || "20000".equals(ec) || "".equals(ec)) {
                    ec = "EBLN0000";
                } else if ("20100".equals(ec)) {
                    String errorCodeTemp = gENEException.getShowMessage();
                    try {
                        ec = getErrCodeFromMsg(errorCodeTemp);
                    } catch (Exception unused) {
                        ec = "20100";
                    }
                    if ("20100".equals(ec)) {
                        ec = "EBLN0000";
                    }
                }
                LifeErrorInfo errorInfo3 = LifeStandard.getErrorInfo(ec, language);
                errorMsg = errorInfo3 != null ? errorInfo3.getShowMsg() : "";
                if ("".equals(errorMsg) || errorMsg == null) {
                    errorMsg = gENEException.getShowMessage();
                }
            } else {
                ec = "EBLN0000";
                LifeErrorInfo errorInfo4 = LifeStandard.getErrorInfo("EBLN0000", language);
                errorMsg = errorInfo4 != null ? errorInfo4.getShowMsg() : "";
                if ("".equals(errorMsg) || errorMsg == null) {
                    errorMsg = gENEException.getMessage();
                }
            }
        } else if (errorCode != null && !"".equals(errorCode)) {
            String str2 = errorCode;
            ec = str2;
            LifeErrorInfo errorInfo5 = LifeStandard.getErrorInfo(str2, language);
            if (errorInfo5 != null) {
                errorMsg = errorInfo5.getShowMsg();
            }
            if ("".equals(errorMsg) || errorMsg == null) {
                errorMsg = (String) context.get("errorMessage");
            }
        } else {
            String retCode = (String) context.get("hostReturnCode");
            if (retCode != null && !"".equals(retCode)) {
                ec = retCode;
                errorMsg = (String) context.get("hostErrorMessage");
            }
        }
        if (ec.equals("EBLN0000")) {
            ErrorMessageJDBC.recordErrorMessage(businessCode, ec, gENEException.getMessage());
        } else if (!ec.equals("0") && !ec.startsWith("RZPT") && ec != "EBLN1000" && !LifeStandard.containsErrCode(ec, language)) {
            ErrorMessageJDBC.recordErrorMessage(businessCode, ec, errorMsg);
        }
        return new LifeErrorInfo(ec, (String) null, errorMsg == null ? "" : errorMsg, 0, (String) null, (String) null);
    }

    public static boolean isFilterValue(String dataName) {
        String[] filter = {"empFlow_Exception", "_ServletRequest", "GENEException"};
        for (int i = 0; i < 3; i += XML_FORMAT_ELEMENT) {
            if (filter[i].equals(dataName)) {
                return true;
            }
        }
        return false;
    }

    public static String getErrCodeFromMsg(String errorMsg) {
        String str = "";
        if (StringUtils.isNotEmpty(errorMsg) && StringUtils.indexOf(errorMsg, "error_code") >= 0) {
            int begPos = StringUtils.indexOf(errorMsg, "error_code:") + 11;
            int endPos = StringUtils.indexOf(errorMsg, "]", begPos);
            str = errorMsg.substring(begPos, endPos);
        }
        return str;
    }

    public String getUrl() {
        return this.url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getExceptionName() {
        return this.exceptionName;
    }

    public void setExceptionName(String exceptionName) {
        this.exceptionName = exceptionName;
    }

    public String getUrlField() {
        return this.urlField;
    }

    public void setUrlField(String urlField) {
        this.urlField = urlField;
    }

    public String getErrorCode() {
        return this.errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }
}
